@@ -1,5 +1,3 @@
-from collections import UserString
-
 letters = {
     'а': 'Cyrillic_a',
     'б': 'Cyrillic_be',
@@ -69,6 +67,8 @@ class Keys:
     UP = BaseKey('Up')
     DOWN = BaseKey('Down')
 
+    INSERT = BaseKey('Insert')
+    DELETE = BaseKey('Delete')
     HOME = BaseKey('Home')
     END = BaseKey('End')
     PAGE_UP = BaseKey('Prior')
@@ -76,6 +76,8 @@ class Keys:
 
     SHIFT = BaseKey('Shift_L')
     CTRL = BaseKey('ctrl')
+    ALT = BaseKey('Alt_L')
     SPACE = BaseKey('space')
 
-keys = Keys()
\ No newline at end of file
+
+keys = Keys()
