@@ -1,10 +1,18 @@
 import re
 import subprocess
-
+from ..os import Shell
 from .human import wind_mouse
 
 
-class Mouse:
+class Center(Shell):
+    def click(self):
+        self.execute("xdotool click --clearmodifiers 2")
+
+
+class Mouse(Shell):
+
+    def __init__(self):
+        self.center = Center()
 
     @property
     def current_position(self):
@@ -13,12 +21,11 @@ class Mouse:
         return {"x": int(x), "y": int(y)}
 
     def _move(self, x, y):
-        subprocess.call(["xdotool", "mousemove", str(x), str(y)])
+        self.execute(f"xdotool mousemove --clearmodifiers --sync {x} {y}")
 
     def move(self, x, y):
         current = self.current_position
         wind_mouse(*current.values(), x, y, move_mouse=self._move)
 
-    @staticmethod
-    def click():
-        subprocess.call(["xdotool", "click", "1"])
+    def click(self):
+        self.execute("xdotool click --clearmodifiers 1")
